Learn R Programming

MGLM (version 0.2.3)

MGLMtune-class: Class "MGLMtune"

Description

A class containing the results from the MGLMtune.

Arguments

Slots

call

object of class "call".

select

object of class "MGLMsparsereg", regularized regression results given by the optimal tuning parameter.

path

object of class "data.frame", the BIC, AIC, log-likelihood and degrees of freedom given each tuning parameter.

select.list

object of class "list", the regularized regression results at each tuning grid point.

Author

Yiwen Zhang and Hua Zhou

Examples

Run this code
showClass("MGLMtune")

Run the code above in your browser using DataLab