powered by
coef extracts estimated model coefficients of class. coefficients is an alias for it.
coef
coefficients
# S4 method for MGLMfit coef(object)# S4 method for MGLMreg coef(object)# S4 method for MGLMsparsereg coef(object)# S4 method for MGLMtune coef(object)
# S4 method for MGLMreg coef(object)
# S4 method for MGLMsparsereg coef(object)
# S4 method for MGLMtune coef(object)
Coefficients extracted from the model object object.
object
For the class "MGLMtune", the function returns model coefficients based on the optimal tuning parameter.
"MGLMtune"
an object for which the extraction of model coefficients is meaningful. One of the following classes "MGLMfit", "MGLMreg", "MGLMsparsereg", "MGLMtune"
"MGLMfit"
"MGLMreg"
"MGLMsparsereg"
Method coef.
library("MGLM") data("rnaseq") data <- rnaseq[, 1:6] mnreg <- MGLMreg(formula = cbind(X1, X2, X3, X4, X5, X6) ~ log(totalReads) + treatment + age + gender, data = rnaseq, dist = "MN") coef(mnreg)
Run the code above in your browser using DataLab