call
object of class "call".
select
object of class "MGLMsparsereg",
regularized regression results given by the optimal tuning parameter.
path
object of class "data.frame",
the BIC, AIC, log-likelihood and degrees of freedom given each tuning parameter.
select.list
object of class "list",
the regularized regression results at each tuning grid point.